#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-terminal-dock-widget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-terminal-dock-widget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-terminal-dock-widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__terminal_dock_widget_t {
    QByteArrayData data[13];
    char stringdata0[211];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__terminal_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__terminal_dock_widget_t qt_meta_stringdata_octave__terminal_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 28), // "octave::terminal_dock_widget"
QT_MOC_LITERAL(1, 29, 16), // "settings_changed"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 20), // "update_prompt_signal"
QT_MOC_LITERAL(4, 68, 25), // "interpreter_output_signal"
QT_MOC_LITERAL(5, 94, 23), // "new_command_line_signal"
QT_MOC_LITERAL(6, 118, 22), // "execute_command_signal"
QT_MOC_LITERAL(7, 141, 17), // "interpreter_event"
QT_MOC_LITERAL(8, 159, 12), // "fcn_callback"
QT_MOC_LITERAL(9, 172, 3), // "fcn"
QT_MOC_LITERAL(10, 176, 13), // "meth_callback"
QT_MOC_LITERAL(11, 190, 4), // "meth"
QT_MOC_LITERAL(12, 195, 15) // "notice_settings"

    },
    "octave::terminal_dock_widget\0"
    "settings_changed\0\0update_prompt_signal\0"
    "interpreter_output_signal\0"
    "new_command_line_signal\0execute_command_signal\0"
    "interpreter_event\0fcn_callback\0fcn\0"
    "meth_callback\0meth\0notice_settings"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__terminal_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,
       4,    1,   63,    2, 0x06 /* Public */,
       5,    1,   66,    2, 0x06 /* Public */,
       5,    0,   69,    2, 0x26 /* Public | MethodCloned */,
       6,    1,   70,    2, 0x06 /* Public */,
       7,    1,   73,    2, 0x06 /* Public */,
       7,    1,   76,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   79,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void octave::terminal_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        terminal_dock_widget *_t = static_cast<terminal_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->settings_changed(); break;
        case 1: _t->update_prompt_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->interpreter_output_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->new_command_line_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->new_command_line_signal(); break;
        case 5: _t->execute_command_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
        case 7: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
        case 8: _t->notice_settings(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (terminal_dock_widget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::settings_changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (terminal_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::update_prompt_signal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (terminal_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::interpreter_output_signal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (terminal_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::new_command_line_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (terminal_dock_widget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::execute_command_signal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (terminal_dock_widget::*_t)(const fcn_callback & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::interpreter_event)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (terminal_dock_widget::*_t)(const meth_callback & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&terminal_dock_widget::interpreter_event)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject octave::terminal_dock_widget::staticMetaObject = {
    { &octave_dock_widget::staticMetaObject, qt_meta_stringdata_octave__terminal_dock_widget.data,
      qt_meta_data_octave__terminal_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::terminal_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::terminal_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__terminal_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::terminal_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void octave::terminal_dock_widget::settings_changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::terminal_dock_widget::update_prompt_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::terminal_dock_widget::interpreter_output_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::terminal_dock_widget::new_command_line_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 5
void octave::terminal_dock_widget::execute_command_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void octave::terminal_dock_widget::interpreter_event(const fcn_callback & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void octave::terminal_dock_widget::interpreter_event(const meth_callback & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
